import httpRequest from '@/utils/axios'
/**
 * 模糊搜索
 */
export function searchUserList(params) {
  return httpRequest.get('/api/live/common/v3/sso-user/search', { params })
}
/**
 * 创建会议
 */
export function createMeeting(data) {
  return httpRequest.post('/api/live/admin/v3/tencent/meeting', data)
}
/**
 * 更新会议
 */
export function updateMeeting(data) {
  return httpRequest.put(`/api/live/admin/v3/tencent/meeting/${data.meeting_id}/update`, data)
}
/**
 * 获取腾讯会议列表
 */
export function getMeetingList(params) {
  return httpRequest.get('/api/live/admin/v3/tencent/meetings', { params })
}
/**
 * 获取腾讯会议列表（不分页）
 */
export function getNonpagedMeetingList(params) {
  return httpRequest.get('/api/live/admin/v3/tencent/meeting/list-by-day', { params })
}
/**
 * 获取腾讯会议详情
 */
export function getMeetingDetails(params) {
  return httpRequest.get(`/api/live/admin/v3/tencent/meeting/${params.meeting_id}/detail`, { params })
}
/**
 * 通过会议code获取腾讯会议详情
 */
export function getMeetingDetailsByCode(params) {
  return httpRequest.get(`/api/live/admin/v3/tencent/meeting/${params.meeting_code}/detail-code`, { params })
}
/**
 * 取消(删除)会议
 */
export function cancelMeeting(params) {
  return httpRequest.post(`/api/live/admin/v3/tencent/meeting/${params.meeting_id}/cancel`, params)
}
/**
 * 终止会议
 */
export function stopMeeting(params) {
  return httpRequest.post(`/api/live/admin/v3/tencent/meeting/${params.meeting_id}/dimiss`, params)
}
/**
 * 获取回放地址
 */
export function getMeetingRecordAddr(params) {
  return httpRequest.post(`/api/live/admin/v3/tencent/meeting/${params.meeting_id}/records/address`, params)
}
/**
 * 导出参会人员
 */
export function exportParticipants(params) {
  return httpRequest({
    url: `/api/live/admin/v3/tencent/meeting/${params.meeting_id}/participants/export`,
    method: 'get',
    params,
    responseType: 'blob'
  })
}
/**
 * 文件上传
 */
export function fileUpload(formData) {
  return httpRequest({
    url: 'https://webapp-pub.oss-cn-beijing.aliyuncs.com',
    method: 'post',
    headers: { 'Content-Type': 'multipart/form-data' },
    timeout: 900000,
    data: formData,
    withCredentials: false
  })
}
// 获取oss signature
export function getSignature() {
  return httpRequest.get('/api/usercenter/aliyun/get-signature')
}
/**
 * 获取时间段内的会议个数
 */
export function getMeetingCount(params) {
  return httpRequest.get('/api/live/admin/v3/tencent/meeting/count', { params })
}
