import { getUser, logout, getRole, getPermissions } from '@/api/account'
// import { getUserRoles, getUserPermissions } from '@/api/system'
import { resetRouter } from '@/router'
const user = {
  state: {
    user: {},
    roles: [],
    isLogin: false,
    isSuperAdmin: false,
    hasRoles: false,
    permissions: []
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setIsLogin(state, isLogin) {
      state.isLogin = isLogin
    },
    setRoles(state, roles) {
      state.roles = roles
    },
    setSuperAdmin(state, isSuperAdmin) {
      state.isSuperAdmin = isSuperAdmin
    },
    setHasRoles(state, hasRoles) {
      state.hasRoles = hasRoles
    },
    setPermissions(state, permissions) {
      state.permissions = permissions.map(item => item.tag)
      state.permissionsList = permissions
    }
  },

  actions: {
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        commit('setIsLogin', false)
        commit('setRoles', [])
        commit('setSuperAdmin', false)
        commit('setHasRoles', false)
        commit('setPermissions', [])
        resetRouter()
        return response
      })
    },
    // 检测登录状态
    async checkLogin({ commit }) {
      // await getUserGrade()
      //   .then(response => {
      //     commit('setUserGrade', response.data.level)
      //   })
      //   .catch(() => {
      //   })
      const isLogin = await getUser()
        .then(res => {
          if (res.code === 0 && res.data && res.data.id) {
            commit('setUser', res.data)
            return true
          } else {
            commit('setUser', {})
            return false
          }
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      commit('setIsLogin', isLogin)
      return isLogin
    },
    // 获取角色
    async checkRoles({ commit }) {
      const hasRoles = await getRole().then(res => {
        let isSuperAdmin = false
        if (res.data && Array.isArray(res.data.items)) {
          res.data.items.forEach(it => {
            if (it.tag === 'administrator') isSuperAdmin = true
          })
          commit('setRoles', res.data.items)
          commit('setSuperAdmin', isSuperAdmin)
          return true
        }
        return false
      }).catch(() => {
        commit('setRoles', [])
        return false
      })
      commit('setHasRoles', hasRoles)
      return hasRoles
    },
    // 获取权限
    async checkPermissions({ commit }) {
      const perms = await getPermissions().then(res => {
        if (res.code === 0 && res.data && res.data.items) {
          commit('setPermissions', res.data.items)
          return res.data.items.map(item => item.tag)
        } else {
          commit('setPermissions', [])
          return []
        }
      }).catch(() => {
        commit('setPermissions', [])
        return []
      })
      return perms
    }
  }
}

export default user
